@@ -1,19 +1,7 @@
 /*
- * Copyright (c) 1996-1998 Stefan Taferner <taferner@kde.org>
+ * SPDX-FileCopyrightText: 1996-1998 Stefan Taferner <taferner@kde.org>
  *
- * This program is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
- * (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
+ * SPDX-License-Identifier: GPL-2.0-or-later
  *
  */
 
@@ -90,14 +78,14 @@ SearchRule::RequiredPart FilterActionForward::requiredPart() const
 QWidget *FilterActionForward::createParamWidget(QWidget *parent) const
 {
     QWidget *addressAndTemplate = new QWidget(parent);
-    QHBoxLayout *layout = new QHBoxLayout(addressAndTemplate);
+    auto *layout = new QHBoxLayout(addressAndTemplate);
     layout->setContentsMargins(0, 0, 0, 0);
 
     QWidget *addressEdit = FilterActionWithAddress::createParamWidget(addressAndTemplate);
     addressEdit->setObjectName(QStringLiteral("addressEdit"));
     layout->addWidget(addressEdit);
 
-    Akonadi::EmailAddressRequester *addressRequester = qobject_cast<Akonadi::EmailAddressRequester *>(addressEdit);
+    auto *addressRequester = qobject_cast<Akonadi::EmailAddressRequester *>(addressEdit);
     Q_ASSERT(addressRequester);
     KLineEdit *lineEdit = addressRequester->lineEdit();
     lineEdit->setClearButtonEnabled(true);
@@ -124,11 +112,7 @@ QWidget *FilterActionForward::createParamWidget(QWidget *parent) const
     templateCombo->setEnabled(templateCombo->count() > 1);
     templateCombo->setToolTip(i18n("The template used when forwarding"));
     templateCombo->setWhatsThis(i18n("Set the forwarding template that will be used with this filter."));
-#if QT_VERSION < QT_VERSION_CHECK(5, 15, 0)
     connect(templateCombo, QOverload<int>::of(&KComboBox::currentIndexChanged), this, &FilterActionForward::filterActionModified);
-#else
-    connect(templateCombo, QOverload<int, const QString &>::of(&KComboBox::currentIndexChanged), this, &FilterActionForward::filterActionModified);
-#endif
     connect(addressRequester, &Akonadi::EmailAddressRequester::textChanged, this, &FilterActionForward::filterActionModified);
 
     return addressAndTemplate;
@@ -136,7 +120,7 @@ QWidget *FilterActionForward::createParamWidget(QWidget *parent) const
 
 void FilterActionForward::applyParamWidgetValue(QWidget *paramWidget)
 {
-    QWidget *addressEdit = paramWidget->findChild<QWidget *>(QStringLiteral("addressEdit"));
+    auto *addressEdit = paramWidget->findChild<QWidget *>(QStringLiteral("addressEdit"));
     Q_ASSERT(addressEdit);
     FilterActionWithAddress::applyParamWidgetValue(addressEdit);
 
@@ -153,7 +137,7 @@ void FilterActionForward::applyParamWidgetValue(QWidget *paramWidget)
 
 void FilterActionForward::setParamWidgetValue(QWidget *paramWidget) const
 {
-    QWidget *addressEdit = paramWidget->findChild<QWidget *>(QStringLiteral("addressEdit"));
+    auto *addressEdit = paramWidget->findChild<QWidget *>(QStringLiteral("addressEdit"));
     Q_ASSERT(addressEdit);
     FilterActionWithAddress::setParamWidgetValue(addressEdit);
 
@@ -174,7 +158,7 @@ void FilterActionForward::setParamWidgetValue(QWidget *paramWidget) const
 
 void FilterActionForward::clearParamWidget(QWidget *paramWidget) const
 {
-    QWidget *addressEdit = paramWidget->findChild<QWidget *>(QStringLiteral("addressEdit"));
+    auto *addressEdit = paramWidget->findChild<QWidget *>(QStringLiteral("addressEdit"));
     Q_ASSERT(addressEdit);
     FilterActionWithAddress::clearParamWidget(addressEdit);
 
