@@ -1,19 +1,7 @@
 /*
- * Copyright (c) 1996-1998 Stefan Taferner <taferner@kde.org>
+ * SPDX-FileCopyrightText: 1996-1998 Stefan Taferner <taferner@kde.org>
  *
- * This program is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
- * (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
+ * SPDX-License-Identifier: GPL-2.0-or-later
  *
  */
 
@@ -49,7 +37,7 @@ FilterActionRewriteHeader::FilterActionRewriteHeader(QObject *parent)
 
 bool FilterActionRewriteHeader::isEmpty() const
 {
-    return mParameter.isEmpty() || mRegExp.isEmpty();
+    return mParameter.isEmpty() || mRegex.pattern().isEmpty();
 }
 
 QString FilterActionRewriteHeader::informationAboutNotValidAction() const
@@ -58,7 +46,7 @@ QString FilterActionRewriteHeader::informationAboutNotValidAction() const
     if (mParameter.isEmpty()) {
         info = i18n("Header not defined");
     }
-    if (mRegExp.isEmpty()) {
+    if (mRegex.pattern().isEmpty()) {
         if (!info.isEmpty()) {
             info += QLatin1Char('\n');
         }
@@ -83,7 +71,7 @@ FilterAction::ReturnCode FilterActionRewriteHeader::process(ItemContext &context
 
     QString value = header->asUnicodeString();
     const QString oldValue = value;
-    const QString newValue = value.replace(mRegExp, mReplacementString);
+    const QString newValue = value.replace(mRegex, mReplacementString);
     if (newValue != oldValue) {
         msg->removeHeader(param.constData());
 
@@ -108,7 +96,7 @@ SearchRule::RequiredPart FilterActionRewriteHeader::requiredPart() const
 QWidget *FilterActionRewriteHeader::createParamWidget(QWidget *parent) const
 {
     QWidget *widget = new QWidget(parent);
-    QHBoxLayout *layout = new QHBoxLayout(widget);
+    auto *layout = new QHBoxLayout(widget);
     layout->setSpacing(4);
     layout->setContentsMargins(0, 0, 0, 0);
 
@@ -129,7 +117,7 @@ QWidget *FilterActionRewriteHeader::createParamWidget(QWidget *parent) const
     label->setFixedWidth(label->sizeHint().width());
     layout->addWidget(label, 0);
 
-    KLineEdit *regExpLineEdit = new KLineEdit(widget);
+    auto *regExpLineEdit = new KLineEdit(widget);
     regExpLineEdit->setClearButtonEnabled(true);
     regExpLineEdit->setTrapReturnKey(true);
     regExpLineEdit->setObjectName(QStringLiteral("search"));
@@ -140,18 +128,14 @@ QWidget *FilterActionRewriteHeader::createParamWidget(QWidget *parent) const
     label->setObjectName(QStringLiteral("label_with"));
     layout->addWidget(label, 0);
 
-    KLineEdit *lineEdit = new KLineEdit(widget);
+    auto *lineEdit = new KLineEdit(widget);
     lineEdit->setObjectName(QStringLiteral("replace"));
     lineEdit->setClearButtonEnabled(true);
     lineEdit->setTrapReturnKey(true);
     layout->addWidget(lineEdit, 1);
 
     setParamWidgetValue(widget);
-#if QT_VERSION < QT_VERSION_CHECK(5, 15, 0)
     connect(comboBox, QOverload<int>::of(&KComboBox::currentIndexChanged), this, &FilterActionRewriteHeader::filterActionModified);
-#else
-    connect(comboBox, QOverload<int, const QString &>::of(&KComboBox::currentIndexChanged), this, &FilterActionRewriteHeader::filterActionModified);
-#endif
     connect(comboBox->lineEdit(), &QLineEdit::textChanged,
             this, &FilterAction::filterActionModified);
     connect(regExpLineEdit, &KLineEdit::textChanged, this, &FilterActionRewriteHeader::filterActionModified);
@@ -175,11 +159,11 @@ void FilterActionRewriteHeader::setParamWidgetValue(QWidget *paramWidget) const
         comboBox->setCurrentIndex(index);
     }
 
-    KLineEdit *regExpLineEdit = paramWidget->findChild<KLineEdit *>(QStringLiteral("search"));
+    auto *regExpLineEdit = paramWidget->findChild<KLineEdit *>(QStringLiteral("search"));
     Q_ASSERT(regExpLineEdit);
-    regExpLineEdit->setText(mRegExp.pattern());
+    regExpLineEdit->setText(mRegex.pattern());
 
-    KLineEdit *lineEdit = paramWidget->findChild<KLineEdit *>(QStringLiteral("replace"));
+    auto *lineEdit = paramWidget->findChild<KLineEdit *>(QStringLiteral("replace"));
     Q_ASSERT(lineEdit);
     lineEdit->setText(mReplacementString);
 }
@@ -192,7 +176,7 @@ void FilterActionRewriteHeader::applyParamWidgetValue(QWidget *paramWidget)
 
     const KLineEdit *regExpLineEdit = paramWidget->findChild<KLineEdit *>(QStringLiteral("search"));
     Q_ASSERT(regExpLineEdit);
-    mRegExp.setPattern(regExpLineEdit->text());
+    mRegex.setPattern(regExpLineEdit->text());
 
     const KLineEdit *lineEdit = paramWidget->findChild<KLineEdit *>(QStringLiteral("replace"));
     Q_ASSERT(lineEdit);
@@ -205,11 +189,11 @@ void FilterActionRewriteHeader::clearParamWidget(QWidget *paramWidget) const
     Q_ASSERT(comboBox);
     comboBox->setCurrentIndex(0);
 
-    KLineEdit *regExpLineEdit = paramWidget->findChild<KLineEdit *>(QStringLiteral("search"));
+    auto *regExpLineEdit = paramWidget->findChild<KLineEdit *>(QStringLiteral("search"));
     Q_ASSERT(regExpLineEdit);
     regExpLineEdit->clear();
 
-    KLineEdit *lineEdit = paramWidget->findChild<KLineEdit *>(QStringLiteral("replace"));
+    auto *lineEdit = paramWidget->findChild<KLineEdit *>(QStringLiteral("replace"));
     Q_ASSERT(lineEdit);
     lineEdit->clear();
 }
@@ -218,7 +202,7 @@ QString FilterActionRewriteHeader::argsAsString() const
 {
     QString result = mParameter;
     result += QLatin1Char('\t');
-    result += mRegExp.pattern();
+    result += mRegex.pattern();
     result += QLatin1Char('\t');
     result += mReplacementString;
 
@@ -239,7 +223,7 @@ void FilterActionRewriteHeader::argsFromString(const QString &argsStr)
     QString result;
 
     result = list[ 0 ];
-    mRegExp.setPattern(list[ 1 ]);
+    mRegex.setPattern(list[ 1 ]);
     mReplacementString = list[ 2 ];
 
     int index = mParameterList.indexOf(result);
