@@ -1,19 +1,7 @@
 /*
- * Copyright (c) 1996-1998 Stefan Taferner <taferner@kde.org>
+ * SPDX-FileCopyrightText: 1996-1998 Stefan Taferner <taferner@kde.org>
  *
- * This program is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
- * (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
+ * SPDX-License-Identifier: GPL-2.0-or-later
  *
  */
 
@@ -50,12 +38,12 @@ public:
     /**
      * @copydoc FilterAction::isEmpty
      */
-    bool isEmpty() const override;
+    Q_REQUIRED_RESULT bool isEmpty() const override;
 
     /**
      * @copydoc FilterAction::createParamWidget
      */
-    QWidget *createParamWidget(QWidget *parent) const override;
+    Q_REQUIRED_RESULT QWidget *createParamWidget(QWidget *parent) const override;
 
     /**
      * @copydoc FilterAction::applyParamWidgetValue
@@ -80,21 +68,21 @@ public:
     /**
      * @copydoc FilterAction::argsAsString
      */
-    QString argsAsString() const override;
+    Q_REQUIRED_RESULT QString argsAsString() const override;
 
     bool argsFromStringInteractive(const QString &argsStr, const QString &filterName) override;
 
-    QString argsAsStringReal() const override;
+    Q_REQUIRED_RESULT QString argsAsStringReal() const override;
 
     /**
      * @copydoc FilterAction::displayString
      */
-    QString displayString() const override;
+    Q_REQUIRED_RESULT QString displayString() const override;
 
     /**
      * @copydoc FilterAction::folderRemoved
      */
-    bool folderRemoved(const Akonadi::Collection &aFolder, const Akonadi::Collection &aNewFolder) override;
+    Q_REQUIRED_RESULT bool folderRemoved(const Akonadi::Collection &aFolder, const Akonadi::Collection &aNewFolder) override;
 
 protected:
     Akonadi::Collection mFolder;
