@@ -1,22 +1,10 @@
 /*
-  Copyright (c) 2015-2019 Montel Laurent <montel@kde.org>
+  SPDX-FileCopyrightText: 2015-2020 Laurent Montel <montel@kde.org>
 
-  This program is free software; you can redistribute it and/or modify it
-  under the terms of the GNU General Public License, version 2, as
-  published by the Free Software Foundation.
-
-  This program is distributed in the hope that it will be useful, but
-  WITHOUT ANY WARRANTY; without even the implied warranty of
-  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-  General Public License for more details.
-
-  You should have received a copy of the GNU General Public License along
-  with this program; if not, write to the Free Software Foundation, Inc.,
-  51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
+  SPDX-License-Identifier: GPL-2.0-only
 */
 
 #include "filterimporterexportergui.h"
-#include "filter/filterimporterexporter.h"
 #include "filter/mailfilter.h"
 
 #include <QApplication>
@@ -29,8 +17,8 @@ Q_DECLARE_METATYPE(MailCommon::FilterImporterExporter::FilterType)
 FilterImporterExporterGui::FilterImporterExporterGui(QWidget *parent)
     : QWidget(parent)
 {
-    QVBoxLayout *mainLayout = new QVBoxLayout(this);
-    QMenuBar *menuBar = new QMenuBar(this);
+    auto *mainLayout = new QVBoxLayout(this);
+    auto *menuBar = new QMenuBar(this);
     mainLayout->addWidget(menuBar);
     QMenu *menuFilter = menuBar->addMenu(QStringLiteral("filter"));
     QAction *act = new QAction(QStringLiteral("KMail filters"), this);
@@ -90,7 +78,7 @@ void FilterImporterExporterGui::importFilters(MailCommon::FilterImporterExporter
 {
     MailCommon::FilterImporterExporter importer(this);
     bool canceled = false;
-    const QList<MailCommon::MailFilter *> filters = importer.importFilters(canceled, type);
+    const QVector<MailCommon::MailFilter *> filters = importer.importFilters(canceled, type);
     if (canceled) {
         mTextEdit->setText(QStringLiteral("Canceled"));
         return;
@@ -109,7 +97,7 @@ int main(int argc, char **argv)
 {
     QApplication app(argc, argv);
 
-    FilterImporterExporterGui *w = new FilterImporterExporterGui();
+    auto *w = new FilterImporterExporterGui();
     w->resize(800, 600);
     w->show();
     app.exec();
