@@ -1,27 +1,13 @@
 /*
 
-  Copyright (c) 2009 Klarälvdalens Datakonsult AB, a KDAB Group company <info@kdab.com>
+  SPDX-FileCopyrightText: 2009 Klarälvdalens Datakonsult AB, a KDAB Group company <info@kdab.com>
 
-   This program is free software; you can redistribute it and/or
-   modify it under the terms of the GNU General Public License as
-   published by the Free Software Foundation; either version 2 of
-   the License or (at your option) version 3 or any later version
-   accepted by the membership of KDE e.V. (or its successor approved
-   by the membership of KDE e.V.), which shall act as a proxy
-   defined in Section 14 of version 3 of the license.
-
-   This program is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-   GNU General Public License for more details.
-
-   You should have received a copy of the GNU General Public License
-   along with this program.  If not, see <https://www.gnu.org/licenses/>.
+   SPDX-License-Identifier: GPL-2.0-only OR GPL-3.0-only OR LicenseRef-KDE-Accepted-GPL
 */
 
 #include "backupjob.h"
 
-#include <Libkdepim/BroadcastStatus>
+#include <PimCommon/BroadcastStatus>
 #include "mailcommon_debug.h"
 #include <CollectionDeleteJob>
 #include <CollectionFetchJob>
@@ -35,7 +21,7 @@
 #include <KMessageBox>
 #include <KTar>
 #include <KZip>
-#include <kio/global.h> //krazy:exclude=camelcase as there is no such
+#include <KIO/Global>
 
 #include <QFileInfo>
 #include <QTimer>
@@ -46,19 +32,9 @@ static const mode_t archivePerms = S_IFREG | 0644;
 BackupJob::BackupJob(QWidget *parent)
     : QObject(parent)
     , mArchiveTime(QDateTime::currentDateTime())
-    , mArchiveType(Zip)
     , mRootFolder(0)
-    , mArchive(nullptr)
     , mParentWidget(parent)
-    , mArchivedMessages(0)
-    , mArchivedSize(0)
-    , mProgressItem(nullptr)
-    , mAborted(false)
-    , mDeleteFoldersAfterCompletion(false)
-    , mRecursive(true)
     , mCurrentFolder(Akonadi::Collection())
-    , mCurrentJob(nullptr)
-    , mDisplayMessageBox(true)
 {
 }
 
@@ -110,7 +86,7 @@ bool BackupJob::queueFolders(const Akonadi::Collection &root)
         // in the mPendingFolders list before all second level children, so that the
         // directories for the first level are written before the directories in the
         // second level, in the archive file.
-        Akonadi::CollectionFetchJob *job
+        auto *job
             = new Akonadi::CollectionFetchJob(root, Akonadi::CollectionFetchJob::FirstLevel);
         job->fetchScope().setAncestorRetrieval(Akonadi::CollectionFetchScope::All);
         job->exec();
@@ -193,7 +169,7 @@ void BackupJob::finish()
     }
 
     const QString archivingStr(i18n("Archiving finished"));
-    KPIM::BroadcastStatus::instance()->setStatusMsg(archivingStr);
+    PimCommon::BroadcastStatus::instance()->setStatusMsg(archivingStr);
 
     if (mProgressItem) {
         mProgressItem->setStatus(archivingStr);
@@ -237,8 +213,7 @@ void BackupJob::archiveNextMessage()
         return;
     }
 
-    Akonadi::Item item = mPendingMessages.front();
-    mPendingMessages.pop_front();
+    const Akonadi::Item item = mPendingMessages.takeFirst();
     qCDebug(MAILCOMMON_LOG) << "Fetching item with ID" << item.id() << "for folder" << mCurrentFolder.name();
 
     mCurrentJob = new Akonadi::ItemFetchJob(item);
@@ -289,7 +264,7 @@ void BackupJob::itemFetchJobResult(KJob *job)
         qCWarning(MAILCOMMON_LOG) << job->errorString();
         abort(i18n("Downloading a message in folder '%1' failed.", mCurrentFolder.name()));
     } else {
-        Akonadi::ItemFetchJob *fetchJob = qobject_cast<Akonadi::ItemFetchJob *>(job);
+        auto *fetchJob = qobject_cast<Akonadi::ItemFetchJob *>(job);
         Q_ASSERT(fetchJob);
         Q_ASSERT(fetchJob->items().size() == 1);
         processMessage(fetchJob->items().constFirst());
@@ -335,7 +310,7 @@ QString BackupJob::subdirPathForCollection(const Akonadi::Collection &collection
     QString path = pathForCollection(collection);
     const int parentDirEndIndex = path.lastIndexOf(collection.name());
     Q_ASSERT(parentDirEndIndex != -1);
-    path = path.left(parentDirEndIndex);
+    path.truncate(parentDirEndIndex);
     path.append(QLatin1Char('.') + collection.name() + QLatin1String(".directory"));
     return path;
 }
@@ -357,7 +332,7 @@ void BackupJob::archiveNextFolder()
     if (mProgressItem) {
         mProgressItem->setStatus(archivingStr);
     }
-    KPIM::BroadcastStatus::instance()->setStatusMsg(archivingStr);
+    PimCommon::BroadcastStatus::instance()->setStatusMsg(archivingStr);
 
     const QString folderName = mCurrentFolder.name();
     bool success = true;
@@ -382,7 +357,7 @@ void BackupJob::archiveNextFolder()
                    mCurrentFolder.name()));
         return;
     }
-    Akonadi::ItemFetchJob *job = new Akonadi::ItemFetchJob(mCurrentFolder);
+    auto *job = new Akonadi::ItemFetchJob(mCurrentFolder);
     job->setProperty("folderName", folderName);
     connect(job, &Akonadi::ItemFetchJob::result, this, &BackupJob::onArchiveNextFolderDone);
 }
@@ -396,7 +371,7 @@ void BackupJob::onArchiveNextFolderDone(KJob *job)
         return;
     }
 
-    Akonadi::ItemFetchJob *fetchJob = qobject_cast<Akonadi::ItemFetchJob *>(job);
+    auto *fetchJob = qobject_cast<Akonadi::ItemFetchJob *>(job);
     mPendingMessages += fetchJob->items();
     archiveNextMessage();
 }
