@@ -1,30 +1,17 @@
 /*
-  Copyright (c) 2013-2019 Montel Laurent <montel@kde.org>
+  SPDX-FileCopyrightText: 2013-2020 Laurent Montel <montel@kde.org>
 
-  This program is free software; you can redistribute it and/or modify
-  it under the terms of the GNU General Public License as published by
-  the Free Software Foundation; either version 2 of the License, or
-  (at your option) any later version.
-
-  This program is distributed in the hope that it will be useful, but
-  WITHOUT ANY WARRANTY; without even the implied warranty of
-  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-  General Public License for more details.
-
-  You should have received a copy of the GNU General Public License along
-  with this program; if not, write to the Free Software Foundation, Inc.,
-  51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
+  SPDX-License-Identifier: GPL-2.0-or-later
 */
 
 #include "numericrulewidgethandler.h"
 #include "search/searchpattern.h"
 
-#include <PimCommon/MinimumComboBox>
-
 #include <KPluralHandlingSpinBox>
 #include <KLocalizedString>
 
 #include <QStackedWidget>
+#include <QComboBox>
 
 using namespace MailCommon;
 
@@ -51,7 +38,8 @@ QWidget *NumericRuleWidgetHandler::createFunctionWidget(
         return nullptr;
     }
 
-    PimCommon::MinimumComboBox *funcCombo = new PimCommon::MinimumComboBox(functionStack);
+    auto funcCombo = new QComboBox(functionStack);
+    funcCombo->setMinimumWidth(50);
     funcCombo->setObjectName(QStringLiteral("numericRuleFuncCombo"));
     for (int i = 0; i < NumericFunctionCount; ++i) {
         funcCombo->addItem(i18n(NumericFunctions[i].displayName));
@@ -70,7 +58,7 @@ QWidget *NumericRuleWidgetHandler::createValueWidget(int number, QStackedWidget
         return nullptr;
     }
 
-    KPluralHandlingSpinBox *numInput = new KPluralHandlingSpinBox(valueStack);
+    auto *numInput = new KPluralHandlingSpinBox(valueStack);
     numInput->setObjectName(QStringLiteral("KPluralHandlingSpinBox"));
     QObject::connect(numInput, SIGNAL(valueChanged(int)),
                      receiver, SLOT(slotValueChanged()));
@@ -82,8 +70,7 @@ QWidget *NumericRuleWidgetHandler::createValueWidget(int number, QStackedWidget
 SearchRule::Function NumericRuleWidgetHandler::currentFunction(
     const QStackedWidget *functionStack) const
 {
-    const PimCommon::MinimumComboBox *funcCombo
-        = functionStack->findChild<PimCommon::MinimumComboBox *>(QStringLiteral("numericRuleFuncCombo"));
+    const auto funcCombo = functionStack->findChild<QComboBox *>(QStringLiteral("numericRuleFuncCombo"));
 
     if (funcCombo && funcCombo->currentIndex() >= 0) {
         return NumericFunctions[funcCombo->currentIndex()].id;
@@ -150,8 +137,7 @@ bool NumericRuleWidgetHandler::handlesField(const QByteArray &field) const
 void NumericRuleWidgetHandler::reset(QStackedWidget *functionStack, QStackedWidget *valueStack) const
 {
     // reset the function combo box
-    PimCommon::MinimumComboBox *funcCombo
-        = functionStack->findChild<PimCommon::MinimumComboBox *>(QStringLiteral("numericRuleFuncCombo"));
+    const auto funcCombo = functionStack->findChild<QComboBox *>(QStringLiteral("numericRuleFuncCombo"));
 
     if (funcCombo) {
         funcCombo->blockSignals(true);
@@ -160,7 +146,7 @@ void NumericRuleWidgetHandler::reset(QStackedWidget *functionStack, QStackedWidg
     }
 
     // reset the value widget
-    KPluralHandlingSpinBox *numInput = valueStack->findChild<KPluralHandlingSpinBox *>(QStringLiteral("KPluralHandlingSpinBox"));
+    auto *numInput = valueStack->findChild<KPluralHandlingSpinBox *>(QStringLiteral("KPluralHandlingSpinBox"));
 
     if (numInput) {
         numInput->blockSignals(true);
@@ -197,8 +183,7 @@ bool NumericRuleWidgetHandler::setRule(QStackedWidget *functionStack, QStackedWi
         }
     }
 
-    PimCommon::MinimumComboBox *funcCombo
-        = functionStack->findChild<PimCommon::MinimumComboBox *>(QStringLiteral("numericRuleFuncCombo"));
+    const auto funcCombo = functionStack->findChild<QComboBox *>(QStringLiteral("numericRuleFuncCombo"));
 
     if (funcCombo) {
         funcCombo->blockSignals(true);
@@ -218,7 +203,7 @@ bool NumericRuleWidgetHandler::setRule(QStackedWidget *functionStack, QStackedWi
         value = 0;
     }
 
-    KPluralHandlingSpinBox *numInput = valueStack->findChild<KPluralHandlingSpinBox *>(QStringLiteral("KPluralHandlingSpinBox"));
+    auto *numInput = valueStack->findChild<KPluralHandlingSpinBox *>(QStringLiteral("KPluralHandlingSpinBox"));
 
     if (numInput) {
         initNumInput(numInput, rule->field());
@@ -242,7 +227,7 @@ bool NumericRuleWidgetHandler::update(const QByteArray &field, QStackedWidget *f
     functionStack->setCurrentWidget(functionStack->findChild<QWidget *>(QStringLiteral("numericRuleFuncCombo")));
 
     // raise the correct value widget
-    KPluralHandlingSpinBox *numInput = valueStack->findChild<KPluralHandlingSpinBox *>(QStringLiteral("KPluralHandlingSpinBox"));
+    auto *numInput = valueStack->findChild<KPluralHandlingSpinBox *>(QStringLiteral("KPluralHandlingSpinBox"));
 
     if (numInput) {
         initNumInput(numInput, field);
